@@ -2,6 +2,7 @@ __version__ = "0.1.0"
 
 
 from . import federation  # noqa
+from .arguments import argument  # noqa
 from .custom_scalar import scalar  # noqa
 from .directive import directive  # noqa
 from .enum import enum  # noqa
@@ -9,6 +10,7 @@ from .field import field  # noqa
 from .lazy_type import LazyType  # noqa
 from .mutation import mutation, subscription  # noqa
 from .permission import BasePermission  # noqa
+from .private import Private  # noqa
 from .scalars import ID  # noqa
 from .schema import Schema  # noqa
 from .type import input, interface, type  # noqa
