@@ -100,3 +100,23 @@ class MissingFieldAnnotationError(Exception):
         )
 
         super().__init__(message)
+
+
+class PrivateStrawberryFieldError(Exception):
+    def __init__(self, field_name: str, type_name: str):
+        message = (
+            f"Field {field_name} on type {type_name} cannot be both "
+            "private and a strawberry.field"
+        )
+
+        super().__init__(message)
+
+
+class MultipleStrawberryArgumentsError(Exception):
+    def __init__(self, field_name: str, argument_name: str):
+        message = (
+            f"Annotation for argument `{argument_name}` on field "
+            f"`{field_name}` cannot have multiple `strawberry.argument`s"
+        )
+
+        super().__init__(message)
