@@ -4,6 +4,8 @@ from typing import List, Optional, Type, cast
 
 from strawberry.utils.typing import is_generic
 
+from .exceptions import MissingFieldAnnotationError
+from .types.type_resolver import _get_fields
 from .types.types import FederationTypeParams, TypeDefinition
 from .utils.str_converters import to_camel_case
 
@@ -22,6 +24,36 @@ def _get_interfaces(cls: Type) -> List[TypeDefinition]:
     return interfaces
 
 
+def _check_field_annotations(cls: Type):
+    """Are any of the dataclass Fields missing type annotations?
+
+    This replicates the check that dataclasses do during creation, but allows a
+    proper Strawberry exception to be raised
+
+    https://github.com/python/cpython/blob/6fed3c85402c5ca704eb3f3189ca3f5c67a08d19/Lib/dataclasses.py#L881-L884
+    """
+    cls_annotations = cls.__dict__.get("__annotations__", {})
+
+    for field_name, value in cls.__dict__.items():
+        if not isinstance(value, dataclasses.Field):
+            # Not a dataclasses.Field. Ignore
+            continue
+
+        if field_name not in cls_annotations:
+            # Field object exists but did not get an annotation
+            raise MissingFieldAnnotationError(field_name)
+
+
+def _wrap_dataclass(cls: Type):
+    """Wrap a strawberry.type class with a dataclass and check for any issues
+    before doing so"""
+
+    # Ensure all Fields have been properly type-annotated
+    _check_field_annotations(cls)
+
+    return dataclasses.dataclass(cls)
+
+
 def _process_type(
     cls,
     *,
@@ -33,9 +65,10 @@ def _process_type(
 ):
     name = name or to_camel_case(cls.__name__)
 
-    wrapped = dataclasses.dataclass(cls)
+    wrapped = _wrap_dataclass(cls)
 
     interfaces = _get_interfaces(wrapped)
+    fields = _get_fields(cls)
 
     wrapped._type_definition = TypeDefinition(
         name=name,
@@ -46,6 +79,7 @@ def _process_type(
         description=description,
         federation=federation or FederationTypeParams(),
         origin=cls,
+        _fields=fields,
     )
 
     return wrapped
