@@ -6,9 +6,11 @@ from strawberry.exceptions import (
     MissingFieldAnnotationError,
     MissingReturnAnnotationError,
     MissingTypesForGenericError,
+    PrivateStrawberryFieldError,
 )
 from strawberry.lazy_type import LazyType
-from strawberry.union import union
+from strawberry.private import Private
+from strawberry.union import StrawberryUnion, union
 from strawberry.utils.str_converters import to_camel_case
 from strawberry.utils.typing import (
     get_args,
@@ -70,7 +72,7 @@ def resolve_type(field_definition: Union[FieldDefinition, ArgumentDefinition]) -
     if is_forward_ref(type):
         # if the type is a forward reference we try to resolve the type by
         # finding it in the global namespace of the module where the field
-        # was intially declared. This will break when the type is not declared
+        # was initially declared. This will break when the type is not declared
         # in the main scope, but we don't want to support that use case
         # see https://mail.python.org/archives/list/typing-sig@python.org/thread/SNKJB2U5S74TWGDWVD6FMXOP63WVIGDR/  # noqa: E501
 
@@ -174,7 +176,7 @@ def resolve_type(field_definition: Union[FieldDefinition, ArgumentDefinition]) -
         if not all(is_type_var(a) for a in args):
             field_definition.type = copy_type_with(type, *args)
 
-    if hasattr(type, "_union_definition"):
+    if isinstance(type, StrawberryUnion):
         field_definition.is_union = True
 
 
@@ -188,8 +190,8 @@ def _get_type_params_for_field(
 
     type = cast(Type, field_definition.type)
 
-    if hasattr(type, "_union_definition"):
-        types = type._union_definition.types
+    if isinstance(type, StrawberryUnion):
+        types = type.types
         type_vars = [t for t in types if is_type_var(t)]
 
         if type_vars:
@@ -344,6 +346,10 @@ def _get_fields(cls: Type) -> List[FieldDefinition]:
             # Use the existing FieldDefinition
             field_definition = field._field_definition
 
+            # Check that the field type is not Private
+            if isinstance(field_definition.type, Private):
+                raise PrivateStrawberryFieldError(field.name, cls.__name__)
+
             if not field_definition.name:
                 field_definition.name = to_camel_case(field_name)
                 field_definition.origin_name = field_name
@@ -367,6 +373,9 @@ def _get_fields(cls: Type) -> List[FieldDefinition]:
             if field_name in field_definitions:
                 continue
 
+            if isinstance(field.type, Private):
+                continue
+
             # Create a FieldDefinition, for fields of Types #1 and #2a
             field_definition = FieldDefinition(
                 origin_name=field.name,
